<?php
if (!class_exists('RBpazt_Theme_Elementor')):
    class RBpazt_Theme_Elementor {
        public function __construct() {
            add_action('wp', [$this, 'register_auto_scripts_frontend']);
            add_filter('elementor/frontend/admin_bar/settings', [$this, 'add_menu_in_admin_bar']);
            add_filter('elementor/controls/animations/additional_animations', [$this, 'add_animations_scroll']);
            add_action('elementor/theme/register_locations', [$this, 'register_locations']);
            add_action('elementor/widgets/widgets_registered', array($this, 'customs_widgets'));
            add_action('elementor/widgets/widgets_registered', array($this, 'include_widgets'));

            add_filter('rbpazt_page_title', [$this, 'hide_title']);
            add_action('wp_enqueue_scripts', [$this, 'global_css'], 20);

            add_action('elementor/icons_manager/native', [$this, 'add_icons_native']);
            add_action('elementor/controls/controls_registered', [$this, 'add_icons']);
            add_action('elementor/editor/after_enqueue_styles', [$this, 'add_style_editor'], 99);

	        add_filter('elementor/fonts/additional_fonts', [$this, 'additional_fonts']);

            // Add Parallax in section
            require get_theme_file_path('includes/elementor/parallax-section.php');
            if (!rbpazt_is_elementor_pro_activated()) {
                require get_theme_file_path('includes/elementor/custom-css.php');
                require get_theme_file_path('includes/elementor/sticky-section.php');
                if (is_admin()) {
                    add_action('manage_elementor_library_posts_columns', [$this, 'admin_columns_headers']);
                    add_action('manage_elementor_library_posts_custom_column', [$this, 'admin_columns_content'], 10, 2);
                }
            }
        }

        public function admin_columns_headers($defaults) {
            $defaults['shortcode'] =  esc_html__('Shortcode', 'rbpazt');

            return $defaults;
        }

        public function admin_columns_content($column_name, $post_id) {
            if ('shortcode' === $column_name) {
                ob_start();
                ?>
                <input class="elementor-shortcode-input" type="text" readonly onfocus="this.select()" value="[hfe_template id='<?php echo esc_attr($post_id); ?>']"/>
                <?php
                ob_get_contents();
            }
        }

        public function add_style_editor() {
            wp_enqueue_style('rbpazt-elementor-editor-icon', get_theme_file_uri('/elementor-icons.css'), [], RBPAZT_VERSION);
        }

        public function add_icons( $manager ) {
            $new_icons = json_decode( '{"rbpazt-icon-almonds":"almonds","rbpazt-icon-carrot":"carrot","rbpazt-icon-cart":"cart","rbpazt-icon-check-square":"check-square","rbpazt-icon-cherry":"cherry","rbpazt-icon-close":"close","rbpazt-icon-collapse":"collapse","rbpazt-icon-copy":"copy","rbpazt-icon-credit-card":"credit-card","rbpazt-icon-delete":"delete","rbpazt-icon-dropdown":"dropdown","rbpazt-icon-expand":"expand","rbpazt-icon-favourite":"favourite","rbpazt-icon-filter":"filter","rbpazt-icon-fish":"fish","rbpazt-icon-headphone":"headphone","rbpazt-icon-history":"history","rbpazt-icon-leaf":"leaf","rbpazt-icon-lettuce":"lettuce","rbpazt-icon-live-support":"live-support","rbpazt-icon-location-1":"location-1","rbpazt-icon-mail-1":"mail-1","rbpazt-icon-minus-square":"minus-square","rbpazt-icon-open-can":"open-can","rbpazt-icon-organic":"organic","rbpazt-icon-paper-bags":"paper-bags","rbpazt-icon-phone-1":"phone-1","rbpazt-icon-phone-plus":"phone-plus","rbpazt-icon-plus-square":"plus-square","rbpazt-icon-radio-checked":"radio-checked","rbpazt-icon-radio-checked2":"radio-checked2","rbpazt-icon-radio-unchecked":"radio-unchecked","rbpazt-icon-rocket":"rocket","rbpazt-icon-search":"search","rbpazt-icon-shield":"shield","rbpazt-icon-shipping":"shipping","rbpazt-icon-shop-leaf":"shop-leaf","rbpazt-icon-short-arrow-left":"short-arrow-left","rbpazt-icon-sprout":"sprout","rbpazt-icon-tag":"tag","rbpazt-icon-tofu":"tofu","rbpazt-icon-user":"user","rbpazt-icon-360":"360","rbpazt-icon-angle-down":"angle-down","rbpazt-icon-angle-left":"angle-left","rbpazt-icon-angle-right":"angle-right","rbpazt-icon-angle-up":"angle-up","rbpazt-icon-arrow-left":"arrow-left","rbpazt-icon-arrow-right":"arrow-right","rbpazt-icon-bars":"bars","rbpazt-icon-calendar":"calendar","rbpazt-icon-cart-empty":"cart-empty","rbpazt-icon-chevron-down":"chevron-down","rbpazt-icon-chevron-left":"chevron-left","rbpazt-icon-chevron-right":"chevron-right","rbpazt-icon-chevron-up":"chevron-up","rbpazt-icon-clock":"clock","rbpazt-icon-cloud-download-alt":"cloud-download-alt","rbpazt-icon-comment":"comment","rbpazt-icon-comments":"comments","rbpazt-icon-edit":"edit","rbpazt-icon-envelope":"envelope","rbpazt-icon-expand-alt":"expand-alt","rbpazt-icon-external-link-alt":"external-link-alt","rbpazt-icon-eye":"eye","rbpazt-icon-file-alt":"file-alt","rbpazt-icon-file-archive":"file-archive","rbpazt-icon-folder-open":"folder-open","rbpazt-icon-folder":"folder","rbpazt-icon-frown":"frown","rbpazt-icon-gift":"gift","rbpazt-icon-grid":"grid","rbpazt-icon-heart-fill":"heart-fill","rbpazt-icon-heart":"heart","rbpazt-icon-home":"home","rbpazt-icon-info-circle":"info-circle","rbpazt-icon-instagram":"instagram","rbpazt-icon-list":"list","rbpazt-icon-long-arrow-alt-down":"long-arrow-alt-down","rbpazt-icon-long-arrow-alt-left":"long-arrow-alt-left","rbpazt-icon-long-arrow-alt-right":"long-arrow-alt-right","rbpazt-icon-long-arrow-alt-up":"long-arrow-alt-up","rbpazt-icon-map-marker-check":"map-marker-check","rbpazt-icon-meh":"meh","rbpazt-icon-minus":"minus","rbpazt-icon-money-bill":"money-bill","rbpazt-icon-pencil-alt":"pencil-alt","rbpazt-icon-plus":"plus","rbpazt-icon-quote":"quote","rbpazt-icon-random":"random","rbpazt-icon-reply-all":"reply-all","rbpazt-icon-reply":"reply","rbpazt-icon-router":"router","rbpazt-icon-shopping-cart":"shopping-cart","rbpazt-icon-sign-out-alt":"sign-out-alt","rbpazt-icon-smile":"smile","rbpazt-icon-spinner":"spinner","rbpazt-icon-square":"square","rbpazt-icon-star":"star","rbpazt-icon-store":"store","rbpazt-icon-sync":"sync","rbpazt-icon-tachometer-alt":"tachometer-alt","rbpazt-icon-th-large":"th-large","rbpazt-icon-th-list":"th-list","rbpazt-icon-thumbtack":"thumbtack","rbpazt-icon-times-circle":"times-circle","rbpazt-icon-times":"times","rbpazt-icon-truck":"truck","rbpazt-icon-video":"video","rbpazt-icon-adobe":"adobe","rbpazt-icon-amazon":"amazon","rbpazt-icon-android":"android","rbpazt-icon-angular":"angular","rbpazt-icon-apper":"apper","rbpazt-icon-apple":"apple","rbpazt-icon-atlassian":"atlassian","rbpazt-icon-behance":"behance","rbpazt-icon-bitbucket":"bitbucket","rbpazt-icon-bitcoin":"bitcoin","rbpazt-icon-bity":"bity","rbpazt-icon-bluetooth":"bluetooth","rbpazt-icon-btc":"btc","rbpazt-icon-centos":"centos","rbpazt-icon-chrome":"chrome","rbpazt-icon-codepen":"codepen","rbpazt-icon-cpanel":"cpanel","rbpazt-icon-discord":"discord","rbpazt-icon-dochub":"dochub","rbpazt-icon-docker":"docker","rbpazt-icon-dribbble":"dribbble","rbpazt-icon-dropbox":"dropbox","rbpazt-icon-drupal":"drupal","rbpazt-icon-ebay":"ebay","rbpazt-icon-facebook":"facebook","rbpazt-icon-figma":"figma","rbpazt-icon-firefox":"firefox","rbpazt-icon-google-plus":"google-plus","rbpazt-icon-google":"google","rbpazt-icon-grunt":"grunt","rbpazt-icon-gulp":"gulp","rbpazt-icon-html5":"html5","rbpazt-icon-joomla":"joomla","rbpazt-icon-link-brand":"link-brand","rbpazt-icon-linkedin":"linkedin","rbpazt-icon-mailchimp":"mailchimp","rbpazt-icon-opencart":"opencart","rbpazt-icon-paypal":"paypal","rbpazt-icon-pinterest-p":"pinterest-p","rbpazt-icon-reddit":"reddit","rbpazt-icon-skype":"skype","rbpazt-icon-slack":"slack","rbpazt-icon-snapchat":"snapchat","rbpazt-icon-spotify":"spotify","rbpazt-icon-trello":"trello","rbpazt-icon-twitter":"twitter","rbpazt-icon-vimeo":"vimeo","rbpazt-icon-whatsapp":"whatsapp","rbpazt-icon-wordpress":"wordpress","rbpazt-icon-yoast":"yoast","rbpazt-icon-youtube":"youtube"}', true );
			$icons     = $manager->get_control( 'icon' )->get_settings( 'options' );
			$new_icons = array_merge(
				$new_icons,
				$icons
			);
			// Then we set a new list of icons as the options of the icon control
			$manager->get_control( 'icon' )->set_settings( 'options', $new_icons );
        }

	    public function additional_fonts($fonts) {
		    $fonts["RBpazt-heading"] = 'system';
		    return $fonts;
	    }

        public function add_icons_native($tabs) {
            $tabs['opal-custom'] = [
                'name'          => 'rbpazt-icon',
                'label'         => esc_html__('RBpazt Icon', 'rbpazt'),
                'prefix'        => 'rbpazt-icon-',
                'displayPrefix' => 'rbpazt-icon-',
                'labelIcon'     => 'fab fa-font-awesome-alt',
                'ver'           => RBPAZT_VERSION,
                'fetchJson'     => get_theme_file_uri('/includes/elementor/icons.json'),
                'native'        => true,
            ];

            return $tabs;
        }

        public function add_menu_in_admin_bar($admin_bar_config) {
            if ($active_kit_id = Elementor\Plugin::$instance->kits_manager->get_active_id()) {
                $admin_bar_config['elementor_edit_page']['children'][] = [
                    'id'    => 'elementor_app_global_settings_editor',
                    'title' => esc_html__('Open Global Settings', 'rbpazt'),
                    'href'  => Elementor\Plugin::$instance->documents->get($active_kit_id)->get_edit_url(),
                ];
            }

            return $admin_bar_config;
        }

        public function global_css() {
            wp_enqueue_style('rbpazt-elementor-css', get_theme_file_uri('elementor.css'), false, RBPAZT_VERSION);
	        wp_style_add_data( 'rbpazt-elementor-css', 'rtl', 'replace' );

            $active_kit_id = Elementor\Plugin::$instance->kits_manager->get_active_id();
            Elementor\Plugin::$instance->kits_manager->frontend_before_enqueue_styles();
            $myvals = get_post_meta($active_kit_id, '_elementor_page_settings', true);
            if (!empty($myvals)) {
                $css = '';
                foreach ($myvals['system_colors'] as $key => $value) {
                    $css .= $value['color'] !== '' ? '--' . $value['_id'] . ':' . $value['color'] . ';' : '';
                }

                $var = "body{{$css}}";
                wp_add_inline_style('rbpazt-style', $var);
            }
        }

        public function register_auto_scripts_frontend() {
            // Register auto scripts frontend
            $files = glob(get_theme_file_path('/assets/js/elementor/*.js'));
            foreach ($files as $file) {
                $file_name = wp_basename($file);
                $handle    = str_replace(".js", '', $file_name);
                $scr       = get_theme_file_uri('/assets/js/elementor/' . $file_name);
                if (file_exists($file)) {
                    wp_register_script('rbpazt-elementor-' . $handle, $scr, ['jquery', 'elementor-frontend'], RBPAZT_VERSION, true);
                }
            }
        }

        public function customs_widgets() {
            $files = glob(get_theme_file_path('/includes/elementor/custom-widgets/*.php'));
            foreach ($files as $file) {
                $file = get_theme_file_path('includes/elementor/custom-widgets/' . wp_basename($file));
                if (file_exists($file)) {
                    require_once $file;
                }
            }
        }

        public function include_widgets($widgets_manager) {
            $files = glob(get_theme_file_path('/includes/elementor/widgets/*.php'));
            foreach ($files as $file) {
                $file = get_theme_file_path('includes/elementor/widgets/' . wp_basename($file));
                if (file_exists($file)) {
                    require_once $file;
                }
            }
        }

        public function add_animations_scroll($animations) {
            $animations['HP Animation'] = [
                'hp-move-up'    => 'Move Up',
                'hp-move-down'  => 'Move Down',
                'hp-move-left'  => 'Move Left',
                'hp-move-right' => 'Move Right',
                'hp-scale-up'   => 'Scale',
            ];

            return $animations;
        }

        public function register_locations($elementor_theme_manager) {
            $hook_result = apply_filters_deprecated('rbpazt_register_elementor_locations', [true], '2.0', 'rbpazt_register_elementor_locations');
            if (apply_filters('rbpazt_register_elementor_locations', $hook_result)) {
                $elementor_theme_manager->register_all_core_location();
            }
        }

        public function hide_title($val) {
            $current_doc = \Elementor\Plugin::instance()->documents->get(get_the_ID());
            if ($current_doc && 'yes' === $current_doc->get_settings('hide_title')) {
                $val = false;
            }

            return $val;
        }
    }
endif;

return new RBpazt_Theme_Elementor();
