<?php
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists('RBpazt_Customize')) {

    class RBpazt_Customize {


        public function __construct() {
            add_action('customize_register', array($this, 'customize_register'));
        }

        /**
         * @param $wp_customize WP_Customize_Manager
         */
        public function customize_register($wp_customize) {
            require_once get_theme_file_path('includes/customizer/customize-control/editor.php');
            /**
             * Theme options.
             */

            $this->init_rbpazt_blog($wp_customize);

            $this->init_rbpazt_social($wp_customize);

            if (rbpazt_is_woocommerce_activated()) {
                $this->init_woocommerce($wp_customize);
            }

            do_action('rbpazt_customize_register', $wp_customize);
        }

        public function init_rbpazt_social($wp_customize) {

            $wp_customize->add_section('rbpazt_social', array(
                'title' => esc_html__('Socials', 'rbpazt'),
            ));

            $wp_customize->add_setting('rbpazt_options_social_share', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_social_share', array(
                'type'    => 'checkbox',
                'section' => 'rbpazt_social',
                'label'   => esc_html__('Show Social Share', 'rbpazt'),
            ));
            $wp_customize->add_setting('rbpazt_options_social_share_facebook', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_social_share_facebook', array(
                'type'    => 'checkbox',
                'section' => 'rbpazt_social',
                'label'   => esc_html__('Share on Facebook', 'rbpazt'),
            ));
            $wp_customize->add_setting('rbpazt_options_social_share_twitter', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_social_share_twitter', array(
                'type'    => 'checkbox',
                'section' => 'rbpazt_social',
                'label'   => esc_html__('Share on Twitter', 'rbpazt'),
            ));
            $wp_customize->add_setting('rbpazt_options_social_share_linkedin', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_social_share_linkedin', array(
                'type'    => 'checkbox',
                'section' => 'rbpazt_social',
                'label'   => esc_html__('Share on Linkedin', 'rbpazt'),
            ));
            $wp_customize->add_setting('rbpazt_options_social_share_google-plus', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_setting('rbpazt_options_social_share_pinterest', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_social_share_pinterest', array(
                'type'    => 'checkbox',
                'section' => 'rbpazt_social',
                'label'   => esc_html__('Share on Pinterest', 'rbpazt'),
            ));
            $wp_customize->add_setting('rbpazt_options_social_share_email', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_social_share_email', array(
                'type'    => 'checkbox',
                'section' => 'rbpazt_social',
                'label'   => esc_html__('Share on Email', 'rbpazt'),
            ));
        }

        /**
         * @param $wp_customize WP_Customize_Manager
         *
         * @return void
         */
        public function init_rbpazt_blog($wp_customize) {

            $wp_customize->add_section('rbpazt_blog_archive', array(
                'title' => esc_html__('Blog', 'rbpazt'),
            ));

            // =========================================
            // Select Style
            // =========================================

            $wp_customize->add_setting('rbpazt_options_blog_style', array(
                'type'              => 'option',
                'default'           => 'standard',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_blog_style', array(
                'section' => 'rbpazt_blog_archive',
                'label'   => esc_html__('Blog style', 'rbpazt'),
                'type'    => 'select',
                'choices' => array(
                    'standard' => esc_html__('Blog Standard', 'rbpazt'),
                    'grid'     => esc_html__('Blog Grid', 'rbpazt'),
                ),
            ));

            $wp_customize->add_setting('rbpazt_options_blog_sidebar', array(
                'type'              => 'option',
                'default'           => 'right',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_blog_sidebar', array(
                'section' => 'rbpazt_blog_archive',
                'label'   => esc_html__('Sidebar Position', 'rbpazt'),
                'type'    => 'select',
                'choices' => array(
                    'left'  => esc_html__('Left', 'rbpazt'),
                    'right' => esc_html__('Right', 'rbpazt'),

                ),
            ));
        }

        /**
         * @param $wp_customize WP_Customize_Manager
         *
         * @return void
         */
        public function init_woocommerce($wp_customize) {

            $wp_customize->add_panel('woocommerce', array(
                'title' => esc_html__('Woocommerce', 'rbpazt'),
            ));

            $wp_customize->add_section('rbpazt_woocommerce_archive', array(
                'title'      => esc_html__('Archive', 'rbpazt'),
                'capability' => 'edit_theme_options',
                'panel'      => 'woocommerce',
                'priority'   => 1,
            ));

            $wp_customize->add_setting('rbpazt_options_woocommerce_archive_layout', array(
                'type'              => 'option',
                'default'           => 'default',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_woocommerce_archive_layout', array(
                'section' => 'rbpazt_woocommerce_archive',
                'label'   => esc_html__('Layout Style', 'rbpazt'),
                'type'    => 'select',
                'choices' => array(
                    'default' => esc_html__('Sidebar', 'rbpazt'),
                    'canvas'  => esc_html__('Canvas Filter', 'rbpazt'),
                ),
            ));

            $wp_customize->add_setting('rbpazt_options_woocommerce_archive_sidebar', array(
                'type'              => 'option',
                'default'           => 'left',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rbpazt_options_woocommerce_archive_sidebar', array(
                'section' => 'rbpazt_woocommerce_archive',
                'label'   => esc_html__('Sidebar Position', 'rbpazt'),
                'type'    => 'select',
                'choices' => array(
                    'left'  => esc_html__('Left', 'rbpazt'),
                    'right' => esc_html__('Right', 'rbpazt'),
                ),
            ));

            // =========================================
            // Single Product
            // =========================================

            $wp_customize->add_section('rbpazt_woocommerce_single', array(
                'title'      => esc_html__('Single Product', 'rbpazt'),
                'capability' => 'edit_theme_options',
                'panel'      => 'woocommerce',
            ));

            $wp_customize->add_setting('rbpazt_options_single_product_gallery_layout', array(
                'type'              => 'option',
                'default'           => 'horizontal',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'sanitize_text_field',
            ));
            $wp_customize->add_control('rbpazt_options_single_product_gallery_layout', array(
                'section' => 'rbpazt_woocommerce_single',
                'label'   => esc_html__('Style', 'rbpazt'),
                'type'    => 'select',
                'choices' => array(
                    'horizontal' => esc_html__('Horizontal', 'rbpazt'),
                    'vertical'   => esc_html__('Vertical', 'rbpazt'),
                    'gallery'    => esc_html__('Gallery', 'rbpazt'),
                    'sticky'     => esc_html__('Sticky', 'rbpazt'),
                ),
            ));

            $wp_customize->add_setting('rbpazt_options_single_product_content_meta', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'rbpazt_sanitize_editor',
                'transport'         => 'refresh'
            ));

            $wp_customize->add_control(new RBpazt_Customize_Control_Editor($wp_customize, 'rbpazt_options_single_product_content_meta', array(
                'section' => 'rbpazt_woocommerce_single',
                'label'   => esc_html__('Single extra description', 'rbpazt'),
            )));


            // =========================================
            // Product
            // =========================================

            $wp_customize->add_section('rbpazt_woocommerce_product', array(
                'title'      => esc_html__('Product Block', 'rbpazt'),
                'capability' => 'edit_theme_options',
                'panel'      => 'woocommerce',
            ));

            $wp_customize->add_setting('rbpazt_options_wocommerce_block_style', array(
                'type'              => 'option',
                'default'           => '0',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'sanitize_text_field',
            ));
            $wp_customize->add_control('rbpazt_options_wocommerce_block_style', array(
                'section' => 'rbpazt_woocommerce_product',
                'label'   => esc_html__('Style', 'rbpazt'),
                'type'    => 'select',
                'choices' => array(
                    '0' => esc_html__('Default', 'rbpazt'),
                ),
            ));

            $wp_customize->add_setting('rbpazt_options_woocommerce_product_hover', array(
                'type'              => 'option',
                'default'           => 'none',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'sanitize_text_field',
            ));
            $wp_customize->add_control('rbpazt_options_woocommerce_product_hover', array(
                'section' => 'rbpazt_woocommerce_product',
                'label'   => esc_html__('Animation Image Hover', 'rbpazt'),
                'type'    => 'select',
                'choices' => array(
                    'none'          => esc_html__('None', 'rbpazt'),
                    'bottom-to-top' => esc_html__('Bottom to Top', 'rbpazt'),
                    'top-to-bottom' => esc_html__('Top to Bottom', 'rbpazt'),
                    'right-to-left' => esc_html__('Right to Left', 'rbpazt'),
                    'left-to-right' => esc_html__('Left to Right', 'rbpazt'),
                    'swap'          => esc_html__('Swap', 'rbpazt'),
                    'fade'          => esc_html__('Fade', 'rbpazt'),
                    'zoom-in'       => esc_html__('Zoom In', 'rbpazt'),
                    'zoom-out'      => esc_html__('Zoom Out', 'rbpazt'),
                ),
            ));

            $wp_customize->add_setting('rbpazt_options_wocommerce_columns_mobile', array(
                'type'              => 'option',
                'default'           => '2',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'sanitize_text_field',
            ));
            $wp_customize->add_control('rbpazt_options_wocommerce_columns_mobile', array(
                'section'     => 'woocommerce_product_catalog',
                'label'       => esc_html__('Products per row on mobile', 'rbpazt'),
                'description' => esc_html__('How many products should be shown per row on mobile?', 'rbpazt'),
                'type'        => 'select',
                'choices'     => array(
                    '1' => esc_html__('1 ', 'rbpazt'),
                    '2' => esc_html__('2', 'rbpazt'),
                ),
            ));

        }
    }
}
return new RBpazt_Customize();
