<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;

class RBpazt_Elementor_Account extends Elementor\Widget_Base
{
    public function get_name()
    {
        return 'rbpazt-account';
    }

    public function get_title()
    {
        return esc_html__('RBpazt Account', 'rbpazt');
    }

    public function get_icon()
    {
        return 'eicon-lock-user';
    }

    public function get_categories()
    {
        return array('rbpazt-addons');
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'account-config',
            [
                'label' => esc_html__('Config', 'rbpazt'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'account_icon',
            [
                'label' => esc_html__('Icon', 'rbpazt'),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'rbpazt-icon- rbpazt-icon-user',
                    'library' => 'rbpazt',
                ],
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'rbpazt'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'rbpazt'),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_responsive_control(
            'account_alignment',
            [
                'label' => esc_html__('Alignment', 'rbpazt'),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'left',
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'rbpazt'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'rbpazt'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'rbpazt'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'label_block' => false,
                'selectors' => [
                    '{{WRAPPER}} .site-header-account' => 'text-align: {{VALUE}};'
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'account-style',
            [
                'label' => esc_html__('Style', 'rbpazt'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'icon_account_size',
            [
                'label' => esc_html__('Size Icon', 'rbpazt'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .site-header-account > a i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__('Icon Color', 'rbpazt'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .site-header-account > a i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'icon_color_hover',
            [
                'label' => esc_html__('Icon Color Hover', 'rbpazt'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .site-header-account > a:hover i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'style-content',
            [
                'label' => esc_html__('Position Hover', 'rbpazt'),
                'type' => Controls_Manager::SELECT,
                'default' => 'left',
                'options' => [
                    'left' => esc_html__('Left', 'rbpazt'),
                    'right' => esc_html__('Right', 'rbpazt'),
                ],
                'prefix_class' => 'header-account-content-'
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('wrapper', 'class', 'site-header-account');
        ?>
        <div <?php echo rbpazt_get_render_attribute_string('wrapper', $this); ?>>
            <?php
            $link_url = "#";
            $html_attr = 'data-toggle=button-side data-target=.site-account-side';
            if (!is_user_logged_in()) {
                add_action('wp_footer', 'rbpazt_header_account_side');
                if (!empty($settings['link']['url'])) {
                    $link_url = $settings['link']['url'];
                }

            }
            ?>
            <a <?php echo is_user_logged_in() ? 'class="my-account-icon"' : esc_attr($html_attr); ?>
                    href="<?php echo esc_url($link_url); ?>">
                <span class="account-user">
                <?php if (!empty($settings['account_icon'])) {
                    \Elementor\Icons_Manager::render_icon($settings['account_icon'], ['aria-hidden' => 'true']);
                } ?>
                </span>
            </a>
            <?php if (is_user_logged_in()) { ?>
                <div class="account-dropdown">
                    <div class="account-wrap">
                        <div class="account-inner dashboard">
                            <?php rbpazt_account_dropdown(); ?>
                        </div>
                    </div>
                </div>
            <?php } ?>
        </div>
        <?php

    }
}

$widgets_manager->register_widget_type(new RBpazt_Elementor_Account());



