<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Plugin;

class RBpazt_Elementor_Side_Template extends Elementor\Widget_Base {
    public function get_name() {
        return 'rbpazt-side-template';
    }

    public function get_title() {
        return esc_html__('RBpazt Side Template', 'rbpazt');
    }

    public function get_categories() {
        return array('rbpazt-addons');
    }

    public function get_script_depends() {
        return ['rbpazt-elementor-side-template'];
    }

    protected function register_controls() {
        $templates = \Elementor\Plugin::instance()->templates_manager->get_source('local')->get_items();

        $options = [
            '0' => '— ' . esc_html__('Select', 'rbpazt') . ' —',
        ];

        $types = [];

        foreach ($templates as $template) {
            $options[$template['template_id']] = $template['title'] . ' (' . $template['type'] . ')';
            $types[$template['template_id']]   = $template['type'];
        }

        $this->start_controls_section(
            'section_config',
            [
                'label' => esc_html__('Config', 'rbpazt'),
            ]
        );

        $this->add_control(
            'template_id',
            [
                'label'       => esc_html__('Choose Template', 'rbpazt'),
                'default'     => 0,
                'type'        => Controls_Manager::SELECT,
                'options'     => $options,
                'types'       => $types,
                'label_block' => 'true',
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_icon',
            [
                'label' => esc_html__('Icon', 'rbpazt'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label'     => esc_html__('Color', 'rbpazt'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .site-header-button .button-content >span' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'icon_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'rbpazt'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .site-header-button .button-content:hover >span' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        if ('publish' == get_post_status($settings['template_id'])) {
            add_action('wp_footer', [$this, 'template_canvas_render']);
        }
        ?>
        <div class="site-header-button">
            <a class="button-content" href="#" data-target="#header-template-<?php echo esc_attr($this->get_id());?>">
                <span class="icon-1"></span>
                <span class="icon-2"></span>
                <span class="icon-3"></span>
            </a>
        </div>
        <?php

    }

    public function template_canvas_render() {
        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('canvas_wrapper', 'class', 'header-button-canvas');
        $this->add_render_attribute('canvas_wrapper', 'id', 'header-template-' . $this->get_id());
        ?>
        <div <?php echo rbpazt_elementor_get_render_attribute_string('canvas_wrapper', $this); // WPCS: XSS ok?>>
            <?php
            if ('publish' !== get_post_status($settings['template_id'])) {
                return;
            }
            ?>
            <div class="button-side-heading">
                <a class="close-button-side" href="#" data-target="#header-template-<?php echo esc_attr($this->get_id());?>"><i class="rbpazt-icon-times"></i></a>
            </div>
            <div class="header-template-canvas">
                <?php
                if (!empty($settings['template_id'])) {
                    echo Plugin::instance()->frontend->get_builder_content_for_display($settings['template_id']);
                } else {
                    echo esc_html__('No Templates', 'rbpazt');
                }
                ?>
            </div>
        </div>
        <div class="button-side-overlay" data-target="#header-template-<?php echo esc_attr($this->get_id());?>"></div>
        <?php
    }
}

$widgets_manager->register_widget_type(new RBpazt_Elementor_Side_Template());


