<?php
if (!function_exists('rbpazt_cart_link_fragment')) {
    /**
     * Cart Fragments
     * Ensure cart contents update when products are added to the cart via AJAX
     *
     * @param array $fragments Fragments to refresh via AJAX.
     *
     * @return array            Fragments to refresh via AJAX
     */
    function rbpazt_cart_link_fragment($fragments) {
        ob_start();
        rbpazt_cart_link();
        $fragments['a.cart-contents'] = ob_get_clean();

        ob_start();
//        rbpazt_handheld_footer_bar_cart_link();
        $fragments['a.footer-cart-contents'] = ob_get_clean();

        return $fragments;
    }
}

if (!function_exists('rbpazt_cart_link')) {
    /**
     * Cart Link
     * Displayed a link to the cart including the number of items present and the cart total
     *
     * @return void
     * @since  1.0.0
     */
    function rbpazt_cart_link() {
        $cart = WC()->cart;
        ?>
        <a class="cart-contents" data-toggle="button-side" data-target=".site-header-cart-side" href="<?php echo esc_url(wc_get_cart_url()); ?>"
           title="<?php esc_attr_e('View your shopping cart', 'rbpazt'); ?>">
            <i class="rbpazt-icon-cart"></i>
            <?php if ($cart): ?>
                <span class="count"><?php echo wp_kses_data(sprintf(_n('%d', '%d', WC()->cart->get_cart_contents_count(), 'rbpazt'), WC()->cart->get_cart_contents_count())); ?></span>
                <?php echo WC()->cart->get_cart_subtotal(); ?>
            <?php endif; ?>
        </a>
        <?php
    }
}

if (!function_exists('rbpazt_header_cart_side')) {
    function rbpazt_header_cart_side() {
        if (rbpazt_is_woocommerce_activated()) {
            ?>
            <div class="site-header-cart-side side-wrap">
                <a href="#" class="close-cart-side close-side"></a>
                <div class="cart-side-heading side-heading">
                    <span class="cart-side-title side-title"><?php echo esc_html__('Shopping cart', 'rbpazt'); ?></span>
                </div>
                <?php the_widget('WC_Widget_Cart', 'title='); ?>
            </div>
            <div class="cart-side-overlay side-overlay"></div>
            <?php
        }
    }
}


if (!function_exists('rbpazt_woocommerce_product_loop_image')) {
    function rbpazt_woocommerce_product_loop_image() {
        ?>
        <div class="product-transition"><?php do_action('rbpazt_woocommerce_product_loop_image') ?></div>
        <?php
    }
}

if (!function_exists('rbpazt_template_loop_product_thumbnail')) {
    function rbpazt_template_loop_product_thumbnail($size = 'woocommerce_thumbnail', $deprecated1 = 0, $deprecated2 = 0) {
        echo rbpazt_get_loop_product_thumbnail();

    }
}

if (!function_exists('rbpazt_get_loop_product_thumbnail')) {
    function rbpazt_get_loop_product_thumbnail($size = 'woocommerce_thumbnail', $deprecated1 = 0, $deprecated2 = 0) {
        global $product;
        if (!$product) {
            return '';
        }
        $gallery    = $product->get_gallery_image_ids();
        $hover_skin = rbpazt_get_theme_option('woocommerce_product_hover', 'none');
        if ($hover_skin == '0' || count($gallery) <= 0) {
            echo '<div class="product-image">' . $product->get_image('shop_catalog') . '</div>';

            return '';
        }
        $image_featured = '<div class="product-image">' . $product->get_image('shop_catalog') . '</div>';
        $image_featured .= '<div class="product-image second-image">' . wp_get_attachment_image($gallery[0], 'shop_catalog') . '</div>';

        echo <<<HTML
<div class="product-img-wrap {$hover_skin}">
    <div class="inner">
        {$image_featured}
    </div>
</div>
HTML;
    }
}

if (!function_exists('woocommerce_template_loop_product_title')) {

    /**
     * Show the product title in the product loop.
     */
    function woocommerce_template_loop_product_title() {
        echo '<h2 class="' . esc_attr(apply_filters('woocommerce_product_loop_title_classes', 'woocommerce-loop-product__title')) . '"><a href="' . esc_url_raw(get_the_permalink()) . '">' . get_the_title() . '</a></h2>';
    }
}

if (!function_exists('rbpazt_woocommerce_get_product_short_description')) {
    function rbpazt_woocommerce_get_product_short_description() {
        global $post;
        if ($post->post_excerpt) {
            ?>
            <div class="short-description">
                <?php echo sprintf('%s', $post->post_excerpt); ?>
            </div>
            <?php
        }
    }
}

if (!function_exists('rbpazt_woocommerce_time_sale')) {
    function rbpazt_woocommerce_time_sale() {
        /**
         * @var $product WC_Product
         */
        global $product;

        if (!$product->is_on_sale()) {
            return;
        }

        $time_sale = get_post_meta($product->get_id(), '_sale_price_dates_to', true);
        if ($time_sale) {
            wp_enqueue_script('rbpazt-countdown');
            $time_sale += (get_option('gmt_offset') * HOUR_IN_SECONDS);
            ?>
            <div class="time-sale">
                <div class="deal-text"><span><?php echo esc_html__('Ends in: ', 'rbpazt'); ?></span></div>
                <div class="rbpazt-countdown" data-countdown="true" data-date="<?php echo esc_html($time_sale); ?>">
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-days"></span>
                        <span class="countdown-label"><?php echo esc_html__('d', 'rbpazt') ?></span>
                    </div>
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-hours"></span>
                        <span class="countdown-label"><?php echo esc_html__('h', 'rbpazt') ?></span>
                    </div>
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-minutes"></span>
                        <span class="countdown-label"><?php echo esc_html__('m', 'rbpazt') ?></span>
                    </div>
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-seconds"></span>
                        <span class="countdown-label"><?php echo esc_html__('s', 'rbpazt') ?></span>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}

if (!function_exists('rbpazt_woocommerce_time_sale_layout_2')) {
    function rbpazt_woocommerce_time_sale_layout_2() {
        /**
         * @var $product WC_Product
         */
        global $product;

        if (!$product->is_on_sale()) {
            return;
        }

        $time_sale = get_post_meta($product->get_id(), '_sale_price_dates_to', true);
        if ($time_sale) {
            wp_enqueue_script('rbpazt-countdown');
            $time_sale += (get_option('gmt_offset') * HOUR_IN_SECONDS);
            ?>
            <div class="time-sale">
                <div class="rbpazt-countdown" data-countdown="true" data-date="<?php echo esc_html($time_sale); ?>">
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-days"></span>
                        <span class="countdown-label"><?php echo esc_html__('Days', 'rbpazt') ?></span>
                    </div>
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-hours"></span>
                        <span class="countdown-label"><?php echo esc_html__('Hours', 'rbpazt') ?></span>
                    </div>
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-minutes"></span>
                        <span class="countdown-label"><?php echo esc_html__('Mins', 'rbpazt') ?></span>
                    </div>
                    <div class="countdown-item">
                        <span class="countdown-digits countdown-seconds"></span>
                        <span class="countdown-label"><?php echo esc_html__('Secs', 'rbpazt') ?></span>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}

if (!function_exists('rbpazt_woocommerce_deal_progress')) {
    function rbpazt_woocommerce_deal_progress() {
        global $product;

        $limit = get_post_meta($product->get_id(), '_deal_quantity', true);
        $sold  = intval(get_post_meta($product->get_id(), '_deal_sales_counts', true));
        if (empty($limit)) {
            return;
        }

        ?>

        <div class="deal-sold">
            <div class="deal-progress">
                <div class="progress-bar">
                    <div class="progress-value" style="width: <?php echo trim($sold / $limit * 100) ?>%"></div>
                </div>
            </div>
            <div class="deal-sold-text">
                <div class="availavle">
                    <span><?php echo esc_html__('Already: ', 'rbpazt'); ?></span><span><?php echo esc_html($sold); ?></span>
                </div>
                <div class="already-sold">
                    <span><?php echo esc_html__('Already Sold: ', 'rbpazt'); ?></span><span><?php echo esc_html($limit); ?></span>
                </div>
            </div>
        </div>

        <?php
    }
}

if (!function_exists('rbpazt_woocommerce_get_product_label_stock')) {
    function rbpazt_woocommerce_get_product_label_stock() {
        /**
         * @var $product WC_Product
         */
        global $product;
        if ($product->get_stock_status() == 'outofstock') {
            echo '<span class="stock-label">' . esc_html__('Out Of Stock', 'rbpazt') . '</span>';
        }
    }
}

if (!function_exists('rbpazt_woocommerce_get_product_category')) {
    function rbpazt_woocommerce_get_product_category() {
        global $product;
        echo wc_get_product_category_list($product->get_id(), ', ', '<div class="posted-in">', '</div>');
    }
}

if (!function_exists('rbpazt_woocommerce_pagination_args')) {

    function rbpazt_woocommerce_pagination_args($args) {
        $args['prev_text'] = '<span>' . esc_html__('Prev', 'rbpazt') . '</span>';
        $args['next_text'] = '<span>' . esc_html__('Next', 'rbpazt') . '</span>';

        return $args;
    }

    add_filter('woocommerce_pagination_args', 'rbpazt_woocommerce_pagination_args', 10, 1);
}


if (!function_exists('rbpazt_quickview_button')) {
    function rbpazt_quickview_button() {
        if (function_exists('woosq_init')) {
            echo do_shortcode('[woosq]');
        }
    }
}

if (!function_exists('rbpazt_compare_button')) {
    function rbpazt_compare_button() {
        if (function_exists('woosc_init')) {
            echo do_shortcode('[woosc]');
        }
    }
}

if (!function_exists('rbpazt_wishlist_button')) {
    function rbpazt_wishlist_button() {
        if (function_exists('woosw_init')) {
            echo do_shortcode('[woosw]');
        }
    }
}

if (!function_exists('rbpazt_wishlist_canvas')) {
    function rbpazt_wishlist_canvas() {
        if (function_exists('woosw_init')) {
            ?>
            <div class="site-wishlist-side side-wrap">
                <a href="#" class="close-wishlist-side close-side"></a>
                <div class="wishlist-side-heading side-heading">
                    <span class="wishlist-side-title side-title"><?php echo esc_html__('Wishlist', 'rbpazt'); ?></span>
                </div>
                <div class="wishlist-side-wrap-content">

                    <div class="rbpazt-wishlist-content-scroll">
                        <div class="rbpazt-wishlist-content">

                        </div>
                    </div>
                    <div class="rbpazt-wishlist-bottom">
                        <a class="button"
                           href="<?php echo esc_url(WPCleverWoosw::get_url(WPCleverWoosw::get_key())); ?>"><?php esc_html_e('Wishlist page', 'rbpazt'); ?></a>
                    </div>
                </div>
            </div>
            <div class="wishlist-side-overlay side-overlay"></div>
            <?php
        }
    }
}

if (!function_exists('rbpazt_woocommerce_single_product_image_thumbnail_html')) {
    function rbpazt_woocommerce_single_product_image_thumbnail_html($image, $attachment_id) {
        return wc_get_gallery_image_html($attachment_id, true);
    }
}

if (!function_exists('rbpazt_button_shop_canvas')) {
    function rbpazt_button_shop_canvas() {
        if (is_active_sidebar('sidebar-woocommerce-shop')) { ?>
            <a href="#" class="filter-toggle" aria-expanded="false">
                <i class="rbpazt-icon-filter"></i><span><?php echo esc_html__('Show filter', 'rbpazt'); ?></span></a>
            <?php
        }
    }
}


if (!function_exists('rbpazt_render_woocommerce_shop_canvas')) {
    function rbpazt_render_woocommerce_shop_canvas() {
        if (is_active_sidebar('sidebar-woocommerce-shop') && rbpazt_is_product_archive()) {
            ?>
            <div id="rbpazt-canvas-filter" class="rbpazt-canvas-filter">
                <span class="filter-close"><?php esc_html_e('HIDE FILTER', 'rbpazt'); ?></span>
                <div class="rbpazt-canvas-filter-wrap">
                    <?php if (rbpazt_get_theme_option('woocommerce_archive_layout') == 'canvas') {
                        dynamic_sidebar('sidebar-woocommerce-shop');
                    }
                    ?>
                </div>
            </div>
            <div class="rbpazt-overlay-filter"></div>
            <?php
        }
    }
}


if (!function_exists('rbpazt_single_product_video_360')) {
    function rbpazt_single_product_video_360() {
        global $product;
        echo '<div class="product-video-360">';
        $images = get_post_meta($product->get_id(), '_product_360_image_gallery', true);
        $video  = get_post_meta($product->get_id(), '_video_select', true);
        if ($images) {
            $array      = explode(',', $images);
            $images_url = [];
            foreach ($array as $id) {
                $url          = wp_get_attachment_image_src($id, 'full');
                $images_url[] = $url[0];
            }

            echo '<a class="product-video-360__btn btn-360" href="#view-360"><i class="rbpazt-icon-360"></i></a>';
            ?>
            <div id="view-360" class="view-360 zoom-anim-dialog mfp-hide">
                <div id="rotateimages" class="opal-loading"
                     data-images="<?php echo esc_attr(implode(',', $images_url)); ?>"></div>
                <div class="view-360-group">
                    <span class='view-360-button view-360-prev'><i class="rbpazt-icon-chevron-left"></i></span>
                    <i class="rbpazt-icon-360 view-360-svg"></i>
                    <span class='view-360-button view-360-next'><i class="rbpazt-icon-chevron-right"></i></span>
                </div>
            </div>
            <?php
        }


        if ($video && wc_is_valid_url($video)) {

            echo '<a class="product-video-360__btn btn-video" href="' . $video . '"><i class="rbpazt-icon-video"></i></a>';
        }

        echo '</div>';
    }
}

if (!function_exists('rbpazt_woocommerce_single_brand')) {
    function rbpazt_woocommerce_single_brand() {
        $id = get_the_ID();

        $terms = get_the_terms($id, 'product_brand');

        if (is_wp_error($terms)) {
            return $terms;
        }

        if (empty($terms)) {
            return false;
        }

        $links = array();

        foreach ($terms as $term) {
            $link = get_term_link($term, 'product_brand');
            if (is_wp_error($link)) {
                return $link;
            }

            $img = get_term_meta($term->term_id, 'product_brand_logo', true);
            $has_class = '';
            if ($img !== "") {
	            $has_class = ' brand-has-image';
                $src = wp_get_attachment_image_src($img, 'thumbnail');
                $links[] = '<a href="' . esc_url($link) . '" rel="tag"><img src="' . $src[0] . '" alt="' . $term->name . '"/></a>';
            } else {
                $links[] = '<a href="' . esc_url($link) . '" rel="tag">' . $term->name . '</a>';
            }

        }

        echo '<div class="product-brand'.esc_attr($has_class).'">' . join('', $links) . '</div>';
    }
}


if (!function_exists('rbpazt_single_product_extra')) {
    function rbpazt_single_product_extra() {
        global $product;
        $product_extra = rbpazt_get_theme_option('single_product_content_meta', '');
        $product_extra = get_post_meta($product->get_id(), '_extra_info', true) !== '' ? get_post_meta($product->get_id(), '_extra_info', true) : $product_extra;
        if ($product_extra !== '') {
            echo '<div class="rbpazt-single-product-extra">' . html_entity_decode($product_extra) . '</div>';
        }
    }
}

class Rbpart_Custom_Walker_Category extends Walker_Category {

    public function start_el( &$output, $category, $depth = 0, $args = array(), $id = 0 ) {
        /** This filter is documented in wp-includes/category-template.php */
        $cat_name = apply_filters(
            'list_cats',
            esc_attr( $category->name ),
            $category
        );

        // Don't generate an element if the category name is empty.
        if ( ! $cat_name ) {
            return;
        }

        $link = '<a class="pf-value" href="' . esc_url( get_term_link( $category ) ) . '" data-val="' . esc_attr( $category->slug ) . '" data-title="' . esc_attr( $category->name ) . '" ';
        if ( $args['use_desc_for_title'] && ! empty( $category->description ) ) {
            /**
             * Filters the category description for display.
             *
             * @param string $description Category description.
             * @param object $category Category object.
             *
             * @since 1.2.0
             *
             */
            $link .= 'title="' . esc_attr( strip_tags( apply_filters( 'category_description', $category->description, $category ) ) ) . '"';
        }

        $link .= '>';
        $link .= $cat_name . '</a>';

        if ( ! empty( $args['feed_image'] ) || ! empty( $args['feed'] ) ) {
            $link .= ' ';

            if ( empty( $args['feed_image'] ) ) {
                $link .= '(';
            }

            $link .= '<a href="' . esc_url( get_term_feed_link( $category->term_id, $category->taxonomy, $args['feed_type'] ) ) . '"';

            if ( empty( $args['feed'] ) ) {
                $alt = ' alt="' . sprintf( esc_html__( 'Feed for all posts filed under %s', 'rbpazt' ), $cat_name ) . '"';
            } else {
                $alt  = ' alt="' . $args['feed'] . '"';
                $name = $args['feed'];
                $link .= empty( $args['title'] ) ? '' : $args['title'];
            }

            $link .= '>';

            if ( empty( $args['feed_image'] ) ) {
                $link .= $name;
            } else {
                $link .= "<img src='" . $args['feed_image'] . "'$alt" . ' />';
            }
            $link .= '</a>';

            if ( empty( $args['feed_image'] ) ) {
                $link .= ')';
            }
        }

        if ( ! empty( $args['show_count'] ) ) {
            $link .= ' (' . number_format_i18n( $category->count ) . ')';
        }
        if ( 'list' == $args['style'] ) {
            $output      .= "\t<li";
            $css_classes = array(
                'cat-item',
                'cat-item-' . $category->term_id,
            );

            if ( ! empty( $args['current_category'] ) ) {
                // 'current_category' can be an array, so we use `get_terms()`.
                $_current_terms = get_terms(
                    $category->taxonomy,
                    array(
                        'include'    => $args['current_category'],
                        'hide_empty' => false,
                    )
                );

                foreach ( $_current_terms as $_current_term ) {
                    if ( $category->term_id == $_current_term->term_id ) {
                        $css_classes[] = 'current-cat pf-active';
                    } elseif ( $category->term_id == $_current_term->parent ) {
                        $css_classes[] = 'current-cat-parent';
                    }
                    while ( $_current_term->parent ) {
                        if ( $category->term_id == $_current_term->parent ) {
                            $css_classes[] = 'current-cat-ancestor';
                            break;
                        }
                        $_current_term = get_term( $_current_term->parent, $category->taxonomy );
                    }
                }
            }

            /**
             * Filters the list of CSS classes to include with each category in the list.
             *
             * @param array $css_classes An array of CSS classes to be applied to each list item.
             * @param object $category Category data object.
             * @param int $depth Depth of page, used for padding.
             * @param array $args An array of wp_list_categories() arguments.
             *
             * @since 4.2.0
             *
             * @see wp_list_categories()
             *
             */
            $css_classes = implode( ' ', apply_filters( 'category_css_class', $css_classes, $category, $depth, $args ) );

            $output .= ' class="' . $css_classes . '"';
            $output .= ">$link\n";
        } elseif ( isset( $args['separator'] ) ) {
            $output .= "\t$link" . $args['separator'] . "\n";
        } else {
            $output .= "\t$link<br />\n";
        }
    }
}

if ( ! function_exists( 'rbpazt_show_categories_dropdown' ) ) {
    function rbpazt_show_categories_dropdown() {
        static $id = 0;
        $args  = array(
            'hide_empty' => 1,
            'parent'     => 0
        );
        $terms = get_terms( 'product_cat', $args );
        if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) {
            ?>
            <div class="search-by-category input-dropdown">
                <div class="input-dropdown-inner rbpazt-scroll-content">
                    <!--                    <input type="hidden" name="product_cat" value="0">-->
                    <a href="#" data-val="0">
                        <span><?php esc_html_e( 'All category', 'rbpazt' ); ?></span>
                        <i class="rbpazt-icon-dropdown"></i>
                    </a>
                    <?php
                    $args_dropdown = array(
                        'id'               => 'product_cat' . $id ++,
                        'show_count'       => 0,
                        'class'            => 'dropdown_product_cat_ajax',
                        'show_option_none' => esc_html__( 'All category', 'rbpazt' ),
                    );
                    wc_product_dropdown_categories( $args_dropdown );
                    ?>
                    <div class="list-wrapper rbpazt-scroll">
                        <ul class="rbpazt-scroll-content">
                            <li class="d-none">
                                <a href="#" data-val="0"><?php esc_html_e( 'All category', 'rbpazt' ); ?></a></li>
                            <?php
                            if ( ! apply_filters( 'rbpazt_show_only_parent_categories_dropdown', false ) ) {
                                $args_list = array(
                                    'title_li'           => false,
                                    'taxonomy'           => 'product_cat',
                                    'use_desc_for_title' => false,
                                    'walker'             => new Rbpart_Custom_Walker_Category(),
                                );
                                wp_list_categories( $args_list );
                            } else {
                                foreach ( $terms as $term ) {
                                    ?>
                                    <li>
                                        <a href="#" data-val="<?php echo esc_attr( $term->slug ); ?>"><?php echo esc_attr( $term->name ); ?></a>
                                    </li>
                                    <?php
                                }
                            }
                            ?>
                        </ul>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}

if (!function_exists('rbpazt_product_search')) {
    /**
     * Display Product Search
     *
     * @return void
     * @uses  rbpazt_is_woocommerce_activated() check if WooCommerce is activated
     * @since  1.0.0
     */
    function rbpazt_product_search() {
        if (rbpazt_is_woocommerce_activated()) {
            static $index = 0;
            $index++;
            ?>
            <div class="site-search ajax-search">
                <div class="widget woocommerce widget_product_search">
                    <div class="ajax-search-result d-none"></div>
                    <form role="search" method="get" class="woocommerce-product-search" action="<?php echo esc_url(home_url('/')); ?>">
                        <label class="screen-reader-text" for="woocommerce-product-search-field-<?php echo isset($index) ? absint($index) : 0; ?>"><?php esc_html_e('Search for:', 'rbpazt'); ?></label>
                        <input type="search" id="woocommerce-product-search-field-<?php echo isset($index) ? absint($index) : 0; ?>" class="search-field" placeholder="<?php echo esc_attr__('Search products&hellip;', 'rbpazt'); ?>" autocomplete="off" value="<?php echo get_search_query(); ?>" name="s"/>
                        <button type="submit" value="<?php echo esc_attr_x('Search', 'submit button', 'rbpazt'); ?>"><?php echo esc_html_x('Search', 'submit button', 'rbpazt'); ?></button>
                        <input type="hidden" name="post_type" value="product"/>
                        <?php rbpazt_show_categories_dropdown(); ?>
                    </form>
                </div>
            </div>
            <?php
        }
    }
}

if (!function_exists('rbpazt_ajax_live_search_template')) {
    function rbpazt_ajax_live_search_template() {
        echo <<<HTML
        <script type="text/html" id="tmpl-ajax-live-search-template">
        <div class="product-item-search">
            <# if(data.url){ #>
            <a class="product-link" href="{{{data.url}}}" title="{{{data.title}}}">
            <# } #>
                <# if(data.img){#>
                <img src="{{{data.img}}}" alt="{{{data.title}}}">
                 <# } #>
                <div class="product-content">
                <h3 class="product-title">{{{data.title}}}</h3>
                <# if(data.price){ #>
                {{{data.price}}}
                 <# } #>
                </div>
                <# if(data.url){ #>
            </a>
            <# } #>
        </div>
        </script>
HTML;
    }
}
add_action('wp_footer', 'rbpazt_ajax_live_search_template');

if (!function_exists('rbpazt_quick_shop')) {
    function rbpazt_quick_shop($id = false) {
        if (isset($_GET['id'])) {
            $id = sanitize_text_field((int)$_GET['id']);
        }
        if (!$id || !rbpazt_is_woocommerce_activated()) {
            return;
        }

        global $post;

        $args = array('post__in' => array($id), 'post_type' => 'product');

        $quick_posts = get_posts($args);

        foreach ($quick_posts as $post) :
            setup_postdata($post);
            woocommerce_template_single_add_to_cart();
        endforeach;

        wp_reset_postdata();

        die();
    }

    add_action('wp_ajax_rbpazt_quick_shop', 'rbpazt_quick_shop');
    add_action('wp_ajax_nopriv_rbpazt_quick_shop', 'rbpazt_quick_shop');

}

if (!function_exists('rbpazt_quick_shop_wrapper')) {
    function rbpazt_quick_shop_wrapper() {
        global $product;
        ?>
        <div class="quick-shop-wrapper">
            <div class="quick-shop-close cross-button"><span><?php esc_html_e('Close', 'rbpazt'); ?></span></div>
            <div class="quick-shop-form">
            </div>
        </div>
        <?php
    }
}

//function rbpazt_ajax_add_to_cart_handler() {
//    WC_Form_Handler::add_to_cart_action();
//    WC_AJAX::get_refreshed_fragments();
//}
//
//add_action('wc_ajax_rbpazt_add_to_cart', 'rbpazt_ajax_add_to_cart_handler');
//add_action('wc_ajax_nopriv_rbpazt_add_to_cart', 'rbpazt_ajax_add_to_cart_handler');
//
//// Remove WC Core add to cart handler to prevent double-add
//remove_action('wp_loaded', array('WC_Form_Handler', 'add_to_cart_action'), 20);

function rbpazt_ajax_add_to_cart_add_fragments($fragments) {
    $all_notices  = WC()->session->get('wc_notices', array());
    $notice_types = apply_filters('woocommerce_notice_types', array('error', 'success', 'notice'));

    ob_start();
    foreach ($notice_types as $notice_type) {
        if (wc_notice_count($notice_type) > 0) {
            wc_get_template("notices/{$notice_type}.php", array(
                'notices' => array_filter($all_notices[$notice_type]),
            ));
        }
    }
    $fragments['notices_html'] = ob_get_clean();

    wc_clear_notices();

    return $fragments;
}

//add_filter('woocommerce_add_to_cart_fragments', 'rbpazt_ajax_add_to_cart_add_fragments');


function rbpazt_add_quantity_field() {
    global $product;

    if (!$product->is_sold_individually() && 'variable' != $product->get_type() && $product->is_purchasable()) {
        woocommerce_quantity_input(array('min_value' => 1, 'max_value' => $product->backorders_allowed() ? '' : $product->get_stock_quantity()));
    }

}

if (!function_exists('rbpazt_product_label')) {
    function rbpazt_product_label() {
        global $product;

        $output = array();

        if ($product->is_on_sale()) {

            $percentage = '';

            if ($product->get_type() == 'variable') {

                $available_variations = $product->get_variation_prices();
                $max_percentage       = 0;

                foreach ($available_variations['regular_price'] as $key => $regular_price) {
                    $sale_price = $available_variations['sale_price'][$key];

                    if ($sale_price < $regular_price) {
                        $percentage = round((($regular_price - $sale_price) / $regular_price) * 100);

                        if ($percentage > $max_percentage) {
                            $max_percentage = $percentage;
                        }
                    }
                }

                $percentage = $max_percentage;
            } elseif (($product->get_type() == 'simple' || $product->get_type() == 'external')) {
                $percentage = round((($product->get_regular_price() - $product->get_sale_price()) / $product->get_regular_price()) * 100);
            }

            if ($percentage) {
                $output[] = '<span class="onsale">-' . $percentage . '%' . '</span>';
            } else {
                $output[] = '<span class="onsale">' . esc_html__('Sale', 'rbpazt') . '</span>';
            }
        }

        if (!$product->is_in_stock()) {
            $output[] = '<span class="out-of-stock">' . esc_html__('Out of stock', 'rbpazt') . '</span>';
        }

        if ($output) {
            echo implode('', $output);
        }
    }
}
add_filter('woocommerce_sale_flash', 'rbpazt_product_label', 10);

if (!function_exists('rbpazt_get_review_counting')) {
    function rbpazt_get_review_counting() {

        global $post;
        $output = array();

        for ($i = 1; $i <= 5; $i++) {
            $args       = array(
                'post_id'    => ($post->ID),
                'meta_query' => array(
                    array(
                        'key'   => 'rating',
                        'value' => $i
                    )
                ),
                'count'      => true
            );
            $output[$i] = get_comments($args);
        }
        return $output;
    }
}

if (!function_exists('rbpazt_single_product_pagination')) {
    /**
     * Single Product Pagination
     *
     * @since 2.3.0
     */
    function rbpazt_single_product_pagination() {

        // Show only products in the same category?
        $in_same_term   = apply_filters('rbpazt_single_product_pagination_same_category', true);
        $excluded_terms = apply_filters('rbpazt_single_product_pagination_excluded_terms', '');
        $taxonomy       = apply_filters('rbpazt_single_product_pagination_taxonomy', 'product_cat');

        $previous_product = rbpazt_get_previous_product($in_same_term, $excluded_terms, $taxonomy);
        $next_product     = rbpazt_get_next_product($in_same_term, $excluded_terms, $taxonomy);

        if ((!$previous_product && !$next_product) || !is_product()) {
            return;
        }

        ?>
        <div class="rbpazt-product-pagination-wrap">
            <nav class="rbpazt-product-pagination" aria-label="<?php esc_attr_e('More products', 'rbpazt'); ?>">
                <?php if ($previous_product) : ?>
                    <a href="<?php echo esc_url($previous_product->get_permalink()); ?>" rel="prev">
                        <i class="rbpazt-icon-angle-left"></i>
                        <span><?php echo esc_html__('prev', 'rbpazt')?></span>
                        <div class="product-item">
                            <?php echo sprintf('%s', $previous_product->get_image()); ?>
                            <div class="rbpazt-product-pagination-content">
                                <span class="rbpazt-product-pagination__title"><?php echo sprintf('%s', $previous_product->get_name()); ?></span>
                                <?php if ($price_html = $previous_product->get_price_html()) : ?>
                                    <span class="price"><?php echo sprintf('%s', $price_html); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                    </a>
                <?php endif; ?>
                <?php if ($next_product) : ?>
                    <a href="<?php echo esc_url($next_product->get_permalink()); ?>" rel="next">
                        <span><?php echo esc_html__('next', 'rbpazt')?></span>
                        <i class="rbpazt-icon-angle-right"></i>
                        <div class="product-item">
                            <?php echo sprintf('%s', $next_product->get_image()); ?>
                            <div class="rbpazt-product-pagination-content">
                                <span class="rbpazt-product-pagination__title"><?php echo sprintf('%s', $next_product->get_name()); ?></span>
                                <?php if ($price_html = $next_product->get_price_html()) : ?>
                                    <span class="price"><?php echo sprintf('%s', $price_html); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                    </a>
                <?php endif; ?>
            </nav><!-- .rbpazt-product-pagination -->
        </div>
        <?php
    }
}

if (!function_exists('rbpazt_button_grid_list_layout')) {
    function rbpazt_button_grid_list_layout() {
        $layout = isset($_GET['layout']) ? $_GET['layout'] : apply_filters('rbpazt_shop_layout', 'grid');

        ?>
        <div class="gridlist-toggle desktop-hide-down">
            <a href="<?php echo esc_url(add_query_arg('layout', 'grid')); ?>"
               class="grid rbpazt-icon-grid <?php echo 'grid' == $layout ? 'active' : ''; ?>"
               title="<?php echo esc_attr__('Grid View', 'rbpazt'); ?>"><span class="screen-reader-text"><?php echo esc_html__('grid button', 'rbpazt'); ?></span></a>
            <a href="<?php echo esc_url(add_query_arg('layout', 'list')); ?>"
               class="list rbpazt-icon-list <?php echo 'list' == $layout ? 'active' : ''; ?>"
               title="<?php echo esc_attr__('List View', 'rbpazt'); ?>"><span class="screen-reader-text"><?php echo esc_html__('list button', 'rbpazt'); ?></span></a>
        </div>
        <?php
    }
}

if (!function_exists('rbpazt_woocommerce_get_product_description')) {
    function rbpazt_woocommerce_get_product_description() {
        global $post;
        $short_description = apply_filters('woocommerce_short_description', $post->post_excerpt);
        if ($short_description) {
            printf('<div class="short-description">%s</div>', $short_description);
        }
    }
}
